1D Data Processing Tutorial | MetaboLabPy

# MetaboLabPy

Advanced NMR Data Processing in Python

## Site Navigation[Skip]

- 1D Data Processing Tutorial
- 2D Data Processing Tutorial

## 1D Data Processing Tutorial

1. Download data at: https://tinyurl.com/metabolomicsData

2. Read 1D data set and process NMR data using the proc1d.py script: Click on Script tab, then click Open Script and select proc1d.py. Click on eXecute Script.

3. Explore the software (e.g. the different tabs, also accessible from the Data menu). What information about the spectra can you obtain?

4. Explore plot menu options options, zoom in and out of the spectra.

5. Manually phase correct first 1D spectrum.

6. Try out different window functions and window function parameters (Processing tab). What is the effect on the resulting NMR spectrum?

7. Change window function back to Exponential and lb to 0.3 Hz. Fourier transform the spectrum again.

8. Manually phase correct all NMR spectra.

9. Data Pre-Processing

> 1. Click Data Pre-Processing

> 2. Check Exclude Region, add 3 exclude regions (region left of the signals at ap-proximately 9.15 ppm, water region around 4.8 ppm and the area of TMSP and right of that signal)

> 3. Check Noise Filtering, set noise region and noise threshold

> 4. Check on Bucket spectra and zoom in on a signal containing region. What ef-fect do different settings have? Click run to see the effect and reset to reset to original spectra

> 5. Check Export DataSet and set the exportPath and fileName by clicking select

> 6. Click run to export the pre-processed data set

> 7. You can use the generated file later to perform statistical data analysis on these NMR spectra

Continue with 2D Data Processing Tutorial

© Christian Ludwig 2020
[Back To Top]